==> ngp-6.x-1.10.tar.gz: ngp/hope/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.1 2010/08/12 20:30:51 seanr Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>">
  <head>
  	<title><?php print $head_title ?></title>
  	<meta http-equiv="content-language" content="<?php print $language->language ?>" />
  	<?php print $meta; ?>
    <?php print $head; ?>
    <?php print $styles; ?>
    <!--[if lte IE 7]>
      <link rel="stylesheet" href="/sites/all/themes/blueprint/blueprint/ie.css" type="text/css" media="screen, projection">
    <![endif]-->
  </head>
  <body class="hope <?php print $body_classes; ?>">
    <div id="header" class="container clearfix">
      <?php if ($header): ?>
        <div class="blocks"><?php print $header; ?></div>
      <?php endif ?>
      <div id="logo-floater">
      <?php
        // Prepare header
        if ($site_name) $site_html = '<span class="title">'. check_plain($site_name) .'</span>';
        if ($site_slogan) $site_html .= '<span class="title">'. check_plain($site_slogan) .'</span>';

        if ($logo || $site_name) {
          print '<h1><a href="'. check_url($front_page) .'" title="'. check_plain($site_name) .'">';
          if ($logo && !theme_get_setting('default_logo')) {
            print '<img src="'. check_url($logo) .'" alt="'. check_plain($site_name) .'" id="logo" />';
          }
          print $site_html .'</a></h1>';
        }
      ?>
      </div>
    </div>
    <div id="hope-background-navigation" class="background">
      <div id="navigation" class="container clearfix">
        <?php if (isset($primary_links)) : ?>
          <?php print theme('links', $primary_links, array('id' => 'primary', 'class' => 'links')) ?>
        <?php endif; ?>
      </div>
    </div>
    <div id="hope-background-body" class="background">
      <div id="hope-background-footer" class="background">
        <div id="content" class="container clearfix">
          <?php if ($top): ?>
            <div id="blocks-top" class="region"><?php print $top; ?></div>
          <?php endif ?>
          
          <div id="body" class="span-14 prepend-1 append-1">
            <?php
              if ($context_links) { 
                print '<div class="context-links">'. $context_links .'</div>';
              }
              
              if ($title != '') {
                print '<h2 class="page-title">'. $title .'</h2>';
              }
              
              if ($tabs != '') {
                print '<div class="tabs">'. $tabs .'</div>';
              }
              
              if ($messages != '') {
                print '<div id="messages">'. $messages .'</div>';
              }
              
              if ($content_top) {
                print $content_top;
              }
              
              print $help; // Drupal already wraps this one in a class      
              
              print $content;
              print $feed_icons;
              
              if ($breadcrumb != '') {
                print $breadcrumb;
              }
            ?>
          </div>
          
          <?php if ($right): ?>
            <div id="blocks-right" class="region span-8 last"><div class="top"><?php print $right; ?></div></div>
          <?php endif ?>
        </div>
      </div>
    </div>
    <div id="footer" class="container clearfix append-bottom">
      <?php if ($footer_message): ?>
        <div id="footer-message" class="prepend-5 span-9"><?php print $footer_message; ?></div>
      <?php endif; ?>
      <?php if (isset($secondary_links)) : ?>
        <div id="footer-links" class="span-5"><?php print theme('links', $secondary_links, array('id' => 'secondary', 'class' => 'links')) ?></div>
      <?php endif; ?>
      <?php if ($footer): ?>
        <?php print $footer; ?>
      <?php endif; ?>
    </div>
    <div class="clear"></div>
    <?php print $scripts ?>
    <?php print $closure; ?>
  </body>
</html>

==> ngp-6.x-1.11.tar.gz: ngp/hope/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.2 2010/08/25 15:18:05 seanr Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>">
  <head>
  	<title><?php print $head_title ?></title>
  	<meta http-equiv="content-language" content="<?php print $language->language ?>" />
  	<?php print $meta; ?>
    <?php print $head; ?>
    <?php print $styles; ?>
    <!--[if lte IE 7]>
      <link rel="stylesheet" href="/sites/all/themes/blueprint/blueprint/ie.css" type="text/css" media="screen, projection">
    <![endif]-->
  </head>
  <body class="hope <?php print $body_classes; ?>">
    <div id="header" class="container clearfix">
      <?php if ($header): ?>
        <div class="blocks"><?php print $header; ?></div>
      <?php endif ?>
      <div id="logo-floater">
      <?php
        // Prepare header
        if ($site_name) $site_html = '<span class="title">'. check_plain($site_name) .'</span>';
        if ($site_slogan) $site_html .= '<span class="title">'. check_plain($site_slogan) .'</span>';

        if ($logo || $site_name) {
          print '<h1><a href="'. check_url($front_page) .'" title="'. check_plain($site_name) .'">';
          if ($logo && !theme_get_setting('default_logo')) {
            print '<img src="'. check_url($logo) .'" alt="'. check_plain($site_name) .'" id="logo" />';
          }
          print $site_html .'</a></h1>';
        }
      ?>
      </div>
    </div>
    <div id="hope-background-navigation" class="background">
      <div id="navigation" class="container clearfix">
        <?php if (isset($primary_links)) print menu_tree('primary-links'); ?>
      </div>
    </div>
    <div id="hope-background-body" class="background">
      <div id="hope-background-footer" class="background">
        <div id="content" class="container clearfix">
          <?php if ($top): ?>
            <div id="blocks-top" class="region"><?php print $top; ?></div>
          <?php endif ?>
          
          <div id="body" class="span-14 prepend-1 append-1">
            <?php
              if ($context_links) { 
                print '<div class="context-links">'. $context_links .'</div>';
              }
              
              if ($title != '') {
                print '<h2 class="page-title">'. $title .'</h2>';
              }
              
              if ($tabs != '') {
                print '<div class="tabs">'. $tabs .'</div>';
              }
              
              if ($messages != '') {
                print '<div id="messages">'. $messages .'</div>';
              }
              
              if ($content_top) {
                print $content_top;
              }
              
              print $help; // Drupal already wraps this one in a class      
              
              print $content;
              print $feed_icons;
              
              if ($breadcrumb != '') {
                print $breadcrumb;
              }
            ?>
          </div>
          
          <?php if ($right): ?>
            <div id="blocks-right" class="region span-8 last"><div class="top"><?php print $right; ?></div></div>
          <?php endif ?>
        </div>
      </div>
    </div>
    <div id="footer" class="container clearfix append-bottom">
      <?php if ($footer_message): ?>
        <div id="footer-message" class="prepend-5 span-9"><?php print $footer_message; ?></div>
      <?php endif; ?>
      <?php if (isset($secondary_links)) : ?>
        <div id="footer-links" class="span-5"><?php print theme('links', $secondary_links, array('id' => 'secondary', 'class' => 'links')) ?></div>
      <?php endif; ?>
      <?php if ($footer): ?>
        <?php print $footer; ?>
      <?php endif; ?>
    </div>
    <div class="clear"></div>
    <?php print $scripts ?>
    <?php print $closure; ?>
  </body>
</html>
